==> payara-embedded-all-5.201-sources.jar: org/glassfish/security/services/config/SecurityConfiguration.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
// Portions Copyright [2016] [Payara Foundation]
package org.glassfish.security.services.config;

import org.jvnet.hk2.config.Attribute;
import org.jvnet.hk2.config.ConfigBeanProxy;
import org.jvnet.hk2.config.Configured;
import org.jvnet.hk2.config.DuckTyped;
import org.jvnet.hk2.config.Element;

import javax.validation.constraints.NotNull;
import java.beans.PropertyVetoException;
import java.util.List;

/**
 * Base interface for all security service configurations.
 * 
 * Each security service configuration has a name, indication of the service
 * configuration being the default when multiple service configurations are
 * present and an optional list of the specific security provider plugins. 
 */
@Configured
public interface SecurityConfiguration extends ConfigBeanProxy {
    /**
     * Gets the name of the security service instance.
     */
    @Attribute(required=true, key=true)
    @NotNull
    public String getName();
    public void setName(String value) throws PropertyVetoException;

    /**
     * Determine if this is the default instance.
     */
    @Attribute(defaultValue = "false", dataType = Boolean.class)
    String getDefault();
    void setDefault(String defaultValue) throws PropertyVetoException;

    /**
     * Gets the list of the security provider plugins used by the security service.
     */
    @Element("security-provider")
    List<SecurityProvider> getSecurityProviders();

    /**
     * Gets a named security provider.
     */
    @DuckTyped
    SecurityProvider getSecurityProviderByName(String name);

    class Duck {
        /**
         * Gets a named security provider.
         */
    	public static SecurityProvider getSecurityProviderByName(SecurityConfiguration securityServiceConfiguration, String name) {
            for (SecurityProvider config : securityServiceConfiguration.getSecurityProviders()) {
                if (config.getProviderName().equals(name)) {
                    return config;
                }
            }
            return null;
        }
    }
}

==> payara-embedded-all-6.2023.10-sources.jar: org/glassfish/security/services/config/SecurityConfiguration.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
// Portions Copyright [2016-2021] [Payara Foundation]
package org.glassfish.security.services.config;

import org.jvnet.hk2.config.Attribute;
import org.jvnet.hk2.config.ConfigBeanProxy;
import org.jvnet.hk2.config.Configured;
import org.jvnet.hk2.config.DuckTyped;
import org.jvnet.hk2.config.Element;

import jakarta.validation.constraints.NotNull;
import java.beans.PropertyVetoException;
import java.util.List;

/**
 * Base interface for all security service configurations.
 * 
 * Each security service configuration has a name, indication of the service
 * configuration being the default when multiple service configurations are
 * present and an optional list of the specific security provider plugins. 
 */
@Configured
public interface SecurityConfiguration extends ConfigBeanProxy {
    /**
     * Gets the name of the security service instance.
     */
    @Attribute(required=true, key=true)
    @NotNull
    public String getName();
    public void setName(String value) throws PropertyVetoException;

    /**
     * Determine if this is the default instance.
     */
    @Attribute(defaultValue = "false", dataType = Boolean.class)
    String getDefault();
    void setDefault(String defaultValue) throws PropertyVetoException;

    /**
     * Gets the list of the security provider plugins used by the security service.
     */
    @Element("security-provider")
    List<SecurityProvider> getSecurityProviders();

    /**
     * Gets a named security provider.
     */
    @DuckTyped
    SecurityProvider getSecurityProviderByName(String name);

    class Duck {
        /**
         * Gets a named security provider.
         */
    	public static SecurityProvider getSecurityProviderByName(SecurityConfiguration securityServiceConfiguration, String name) {
            for (SecurityProvider config : securityServiceConfiguration.getSecurityProviders()) {
                if (config.getProviderName().equals(name)) {
                    return config;
                }
            }
            return null;
        }
    }
}
